@@ -9,9 +9,14 @@ package Net::Songkick::Performance;
 use strict;
 use warnings;
 use Moose;
+use Moose::Util::TypeConstraints;
 
 use Net::Songkick::Artist;
 
+coerce 'Net::Songkick::Performance',
+  from 'HashRef',
+  via { Net::Songkick::Performance->new($_) };
+
 has $_ => (
     is => 'ro',
     isa => 'Str',
@@ -20,35 +25,9 @@ has $_ => (
 has artist => (
     is => 'ro',
     isa => 'Net::Songkick::Artist',
+    coerce => 1,
 );
 
-=head1 METHODS
-
-=head2 Net::Songkick::Performance->new_from_xml
-
-Creates a new Net::Songkick::Performance object from an XML::Element object
-that has been created from a <performance> ... </performance> element in the
-XML returned from a Songkick API request.
-
-=cut
-
-sub new_from_xml {
-    my $class = shift;
-    my ($xml) = @_;
-
-    my $self = {};
-
-    for (qw[displayName billing billingIndex id]) {
-        $self->{$_} = $xml->findvalue("\@$_");
-    }
-
-    $self->{artist} = Net::Songkick::Artist->new_from_xml(
-        ($xml->findnodes('artist'))[0]
-    );
-
-    return $class->new($self);
-}
-
 =head1 AUTHOR
 
 Dave Cross <dave@mag-sol.com>
